clc,clear all, close all

% Add path of example
addpath('./Square');
% load geometry
load coordinates.dat; 
eval('load elements.dat;','elements3=[];');
eval('load neumann.dat;' ,'neumann=[];');
load dirichlet.dat;


for k=1:6
  % refine mesh
  [coordinates,elements,dirichlet,neumann] = ...
              refine(coordinates,elements,dirichlet,neumann);
  % compute indices of free nodes 
  FreeNodes = setdiff(1:size(coordinates,1),unique(dirichlet));


  % Initialize A,M, and b
  A1 = sparse(size(coordinates,1),size(coordinates,1));
  b1 = sparse(size(coordinates,1),1);

  % Assembly stiffness matrix
  tic
  for j = 1:size(elements,1)
    A1(elements(j,:),elements(j,:)) = A1(elements(j,:),elements(j,:)) ...
        + stima3(coordinates(elements(j,:),:));
  end
  timeQuad(k) = toc;
  tic
  
  % Volume Forces
  for j = 1:size(elements,1)
    b1(elements(j,:)) = b1(elements(j,:)) + ...
        det([1,1,1; coordinates(elements(j,:),:)']) * ...
        f(sum(coordinates(elements(j,:),:))/3)/6;
  end

  % Neumann conditions
  for j = 1 : size(neumann,1)
    b1(neumann(j,:))=b1(neumann(j,:)) + norm(coordinates(neumann(j,1),:)- ...
        coordinates(neumann(j,2),:)) * g(sum(coordinates(neumann(j,:),:))/2)/2;
  end

  % Dirichlet conditions 
  u1 = sparse(size(coordinates,1),1);
  u1(unique(dirichlet)) = uD(coordinates(unique(dirichlet),:));
  b1 = b1 - A1 * u1;
 

  % Computation of the solution
  u1(FreeNodes) = A1(FreeNodes,FreeNodes) \ b1(FreeNodes);
  
  % computation max error
  err1(k)=max(abs(u1-uD(coordinates)));
  
  dof(k)=length(FreeNodes);
  
  % graphic representation
  figure(1)
  show(elements,[],coordinates,full(u1));
  title('Quadrature Rule')
  view(2),shading interp
  colorbar
  figure(2)
  show(elements,[],coordinates,full(u2));
  title('Lumped Matrix')
  view(2),shading interp
  colorbar
  
end

% plotte exakte Loesung
figure(3)
show(elements,[],coordinates,uD(coordinates));
view(2), shading interp,colorbar

% plot times
figure(5)
loglog(dof,timeLumped,'-r*', dof, timeQuad,'-b*')

